summaryrefslogtreecommitdiff
path: root/source4/libads
diff options
context:
space:
mode:
authorStefan Metzmacher <metze@samba.org>2004-05-25 16:24:13 +0000
committerGerald (Jerry) Carter <jerry@samba.org>2007-10-10 12:56:15 -0500
commitf9d8f8843dc0ab8c9d59abde7222e0f118b86b5d (patch)
tree8c6360be102dee63e893526ac7128e9cd52d362c /source4/libads
parent59e739a2f9f4b10f5f6184ef397f034d09959f26 (diff)
downloadsamba-f9d8f8843dc0ab8c9d59abde7222e0f118b86b5d.tar.gz
samba-f9d8f8843dc0ab8c9d59abde7222e0f118b86b5d.tar.bz2
samba-f9d8f8843dc0ab8c9d59abde7222e0f118b86b5d.zip
r884: convert samba4 to use [u]int32_t instead of [u]int32
metze (This used to be commit 0e5517d937a2eb7cf707991d1c7498c1ab456095)
Diffstat (limited to 'source4/libads')
-rw-r--r--source4/libads/ads_ldap.c8
-rw-r--r--source4/libads/ads_status.c4
-rw-r--r--source4/libads/disp_sec.c4
-rw-r--r--source4/libads/ldap.c16
-rw-r--r--source4/libads/ldap_printer.c8
-rw-r--r--source4/libads/sasl.c8
-rw-r--r--source4/libads/util.c2
7 files changed, 25 insertions, 25 deletions
diff --git a/source4/libads/ads_ldap.c b/source4/libads/ads_ldap.c
index 944cb1599c..b9e07e4c33 100644
--- a/source4/libads/ads_ldap.c
+++ b/source4/libads/ads_ldap.c
@@ -35,7 +35,7 @@ NTSTATUS ads_name_to_sid(ADS_STRUCT *ads,
ADS_STATUS rc;
void *res = NULL;
char *ldap_exp;
- uint32 t;
+ uint32_t t;
NTSTATUS status = NT_STATUS_UNSUCCESSFUL;
char *escaped_name = escape_ldap_string_alloc(name);
char *escaped_realm = escape_ldap_string_alloc(ads->config.realm);
@@ -70,7 +70,7 @@ NTSTATUS ads_name_to_sid(ADS_STRUCT *ads,
goto done;
}
- if (!ads_pull_uint32(ads, res, "sAMAccountType", &t)) {
+ if (!ads_pull_uint32_t(ads, res, "sAMAccountType", &t)) {
DEBUG(1,("No sAMAccountType for %s !?\n", name));
goto done;
}
@@ -104,7 +104,7 @@ NTSTATUS ads_sid_to_name(ADS_STRUCT *ads,
void *msg = NULL;
char *ldap_exp = NULL;
char *sidstr = NULL;
- uint32 atype;
+ uint32_t atype;
NTSTATUS status = NT_STATUS_UNSUCCESSFUL;
if (!(sidstr = sid_binstring(sid))) {
@@ -126,7 +126,7 @@ NTSTATUS ads_sid_to_name(ADS_STRUCT *ads,
goto done;
}
- if (!ads_pull_uint32(ads, msg, "sAMAccountType", &atype)) {
+ if (!ads_pull_uint32_t(ads, msg, "sAMAccountType", &atype)) {
goto done;
}
diff --git a/source4/libads/ads_status.c b/source4/libads/ads_status.c
index 463f647f9c..9ad07bce99 100644
--- a/source4/libads/ads_status.c
+++ b/source4/libads/ads_status.c
@@ -96,7 +96,7 @@ NTSTATUS ads_ntstatus(ADS_STATUS status)
*/
const char *ads_errstr(ADS_STATUS status)
{
- uint32 msg_ctx;
+ uint32_t msg_ctx;
static char *ret;
SAFE_FREE(ret);
@@ -116,7 +116,7 @@ const char *ads_errstr(ADS_STATUS status)
#ifdef HAVE_GSSAPI
case ENUM_ADS_ERROR_GSS:
{
- uint32 minor;
+ uint32_t minor;
gss_buffer_desc msg1, msg2;
msg1.value = NULL;
diff --git a/source4/libads/disp_sec.c b/source4/libads/disp_sec.c
index c9de447e69..0d8954a978 100644
--- a/source4/libads/disp_sec.c
+++ b/source4/libads/disp_sec.c
@@ -21,7 +21,7 @@
#include "includes.h"
static struct perm_mask_str {
- uint32 mask;
+ uint32_t mask;
const char *str;
} perms[] = {
{SEC_RIGHTS_FULL_CTRL, "[Full Control]"},
@@ -50,7 +50,7 @@ static struct perm_mask_str {
};
/* convert a security permissions into a string */
-static void ads_disp_perms(uint32 type)
+static void ads_disp_perms(uint32_t type)
{
int i = 0;
int j = 0;
diff --git a/source4/libads/ldap_printer.c b/source4/libads/ldap_printer.c
index 1448074ea0..dee53e5f1a 100644
--- a/source4/libads/ldap_printer.c
+++ b/source4/libads/ldap_printer.c
@@ -118,7 +118,7 @@ static BOOL map_dword(TALLOC_CTX *ctx, ADS_MODLIST *mods,
if (value->type != REG_DWORD)
return False;
- str_value = talloc_asprintf(ctx, "%d", *((uint32 *) value->data_p));
+ str_value = talloc_asprintf(ctx, "%d", *((uint32_t *) value->data_p));
status = ads_mod_str(ctx, mods, value->valuename, str_value);
return ADS_ERR_OK(status);
}
@@ -148,7 +148,7 @@ static BOOL map_multi_sz(TALLOC_CTX *ctx, ADS_MODLIST *mods,
{
char **str_values = NULL;
smb_ucs2_t *cur_str = (smb_ucs2_t *) value->data_p;
- uint32 size = 0, num_vals = 0, i=0;
+ uint32_t size = 0, num_vals = 0, i=0;
ADS_STATUS status;
if (value->type != REG_MULTI_SZ)
@@ -268,7 +268,7 @@ WERROR get_remote_printer_publishing_data(struct cli_state *cli,
char *printername, *servername;
REGVAL_CTR dsdriver_ctr, dsspooler_ctr;
BOOL got_dsdriver = False, got_dsspooler = False;
- uint32 needed, i;
+ uint32_t needed, i;
POLICY_HND pol;
asprintf(&servername, "\\\\%s", cli->desthost);
@@ -341,7 +341,7 @@ BOOL get_local_printer_publishing_data(TALLOC_CTX *mem_ctx,
ADS_MODLIST *mods,
NT_PRINTER_DATA *data)
{
- uint32 key,val;
+ uint32_t key,val;
for (key=0; key < data->num_keys; key++) {
REGVAL_CTR ctr = data->keys[key].values;
diff --git a/source4/libads/sasl.c b/source4/libads/sasl.c
index 1ab71c6ee5..e4c33aec4c 100644
--- a/source4/libads/sasl.c
+++ b/source4/libads/sasl.c
@@ -33,7 +33,7 @@ static ADS_STATUS ads_sasl_spnego_ntlmssp_bind(ADS_STRUCT *ads)
DATA_BLOB blob, chal1, chal2, auth;
uint8 challenge[8];
uint8 nthash[24], lmhash[24], sess_key[16];
- uint32 neg_flags;
+ uint32_t neg_flags;
struct berval cred, *scred;
ADS_STATUS status;
int rc;
@@ -234,19 +234,19 @@ failed:
*/
static ADS_STATUS ads_sasl_gssapi_bind(ADS_STRUCT *ads)
{
- uint32 minor_status;
+ uint32_t minor_status;
gss_name_t serv_name;
gss_buffer_desc input_name;
gss_ctx_id_t context_handle;
gss_OID mech_type = GSS_C_NULL_OID;
gss_buffer_desc output_token, input_token;
- uint32 ret_flags, conf_state;
+ uint32_t ret_flags, conf_state;
struct berval cred;
struct berval *scred;
int i=0;
int gss_rc, rc;
uint8 *p;
- uint32 max_msg_size;
+ uint32_t max_msg_size;
char *sname;
unsigned sec_layer;
ADS_STATUS status;
diff --git a/source4/libads/util.c b/source4/libads/util.c
index f8c9a312bb..f7dc219790 100644
--- a/source4/libads/util.c
+++ b/source4/libads/util.c
@@ -29,7 +29,7 @@ ADS_STATUS ads_change_trust_account_password(ADS_STRUCT *ads, char *host_princip
char *new_password;
char *service_principal = NULL;
ADS_STATUS ret;
- uint32 sec_channel_type;
+ uint32_t sec_channel_type;
if ((password = secrets_fetch_machine_password(lp_workgroup(), NULL, &sec_channel_type)) == NULL) {
DEBUG(1,("Failed to retrieve password for principal %s\n", host_principal));
diff --git a/source4/libads/ldap.c b/source4/libads/ldap.c
index 8039d3d1d4..9161c35692 100644
--- a/source4/libads/ldap.c
+++ b/source4/libads/ldap.c
@@ -985,7 +985,7 @@ char *ads_ou_string(const char *org_unit)
add a machine account to the ADS server
*/
static ADS_STATUS ads_add_machine_acct(ADS_STRUCT *ads, const char *hostname,
- uint32 account_type,
+ uint32_t account_type,
const char *org_unit)
{
ADS_STATUS ret, status;
@@ -1107,7 +1107,7 @@ static void dump_binary(const char *field, struct berval **values)
}
struct uuid {
- uint32 i1;
+ uint32_t i1;
uint16 i2;
uint16 i3;
uint8 s[8];
@@ -1314,7 +1314,7 @@ int ads_count_replies(ADS_STRUCT *ads, void *res)
* @return status of join
**/
ADS_STATUS ads_join_realm(ADS_STRUCT *ads, const char *hostname,
- uint32 account_type, const char *org_unit)
+ uint32_t account_type, const char *org_unit)
{
ADS_STATUS status;
LDAPMessage *res;
@@ -1737,15 +1737,15 @@ char **ads_pull_strings_range(ADS_STRUCT *ads,
}
/**
* pull a single uint32 from a ADS result
* @param ads connection to ads server
* @param msg Results of search
* @param field Attribute to retrieve
* @param v Pointer to int to store result
* @return boolean inidicating success
*/
-BOOL ads_pull_uint32(ADS_STRUCT *ads,
- void *msg, const char *field, uint32 *v)
+BOOL ads_pull_uint32_t(ADS_STRUCT *ads,
+ void *msg, const char *field, uint32_t *v)
{
char **values;
@@ -1921,7 +1921,7 @@ char *ads_pull_username(ADS_STRUCT *ads, TALLOC_CTX *mem_ctx, void *msg)
* @param usn Pointer to retrieved update serial number
* @return status of search
**/
-ADS_STATUS ads_USN(ADS_STRUCT *ads, uint32 *usn)
+ADS_STATUS ads_USN(ADS_STRUCT *ads, uint32_t *usn)
{
const char *attrs[] = {"highestCommittedUSN", NULL};
ADS_STATUS status;
@@ -1935,7 +1935,7 @@ ADS_STATUS ads_USN(ADS_STRUCT *ads, uint32 *usn)
return ADS_ERROR(LDAP_NO_RESULTS_RETURNED);
}
- ads_pull_uint32(ads, res, "highestCommittedUSN", usn);
+ ads_pull_uint32_t(ads, res, "highestCommittedUSN", usn);
ads_msgfree(ads, res);
return ADS_SUCCESS;
}
@@ -1737,15 +1737,15 @@ char **ads_pull_strings_range(ADS_STRUCT *ads,
}
/**
- * pull a single uint32 from a ADS result
+ * pull a single uint32_t from a ADS result
* @param ads connection to ads server
* @param msg Results of search